/* Microsoft SQL Server - Scripting		*/
/* Database: ReqPro				*/
/* Creation Date 11/12/98 11:30:13 		*/
/* Version: 5.01.0000                           */

/* Notes:  Creates all ReqPro Tables. */

/* If the default Login and User scheme has been used, then create all */
/* objects under the ReqPro user.  Otherwise, create them under */
/* the current Login. */

/* History: */
/* DATE         DEVELOPER  	VERSION    	DESCRIPTION */
/* 11/09/2000 	Pinkerton    	5.01.0000  	Added table: */
/*                                  			RqDocumentTypeTemplates */
/* 11/20/2000 	Pinkerton    	5.01.0000  	Added field: */
/*                                  			RqDocuments.ComposerType */
/* 11/27/2000 	Pinkerton    	5.01.0000  	Added table: */
/*                                  			RqDocumentEntries */
/* 12/21/2000 	Pinkerton  		5.00.0111  	Made RqRequirementTypeUsers.ReqTextAccessRights nullable */
/*                                  		Made RqRequirementTypeUsers.TraceabilityAccessRights nullable */
/* 03/09/2001 	Pinkerton    	5.01.0000  	Added tables: */
/*                                  			RqPackages */
/*                                  			RqPackageElements */
/* 04/30/2001 	Pinkerton    	5.01.0000  	Removed tables: */
/*                                  			RqDocumentTypeTemplates */
/*                                  			RqDocumentEntries */
/*                                  		Removed field: */
/*                                  			RqDocuments.ComposerType */
/* 05/17/2001 	Pinkerton    	5.01.0000  	Added fields: */
/*                                  			RqRequirements.SuspectDateTime */
/*                                  			RqProjects.XMLVersion */
/* 06/26/2001 	Goossen    	5.01.0000  	Added indices: */
/*                                  			RqPackages.ProjectID, ParentID */
/*                                  			RqPackageElements.RequirementID, DocumentID, ViewID */
/* 09/10/2001 	Goossen    	5.01.0000  	Removed indices: */
/*                                  			RqPackages.ProjectID*/
/*                                  			RqPackageElements.DocumentID, ViewID */
/* 03/15/2002 	Goossen    	5.01.0000  	Added unique indices: */
/*                                  			RqPackageElements.RequirementID, */ 
/*                                  			RqPackageElements.DocumentID, */
/*                                  			RqPackageElements.ViewID, */

/* 12/05/2007     Driscoll    7.1         Added new tables RqPackageUsers and RqResources */

/* 09/24/2009     Chalini    7.1.1.000    Change the schema script to use nvarchar instead of varchar. */
/*                                           to store requirement text information                     */
/*                                           in RqRequirements and RqRequirementHistory                */
/* 09/28/2010     Fabian     7.1.1.400    Change the schema script to back out nvarchar and ntext to varchar and text data types. */
setuser
go

If exists (select * from sysusers where uid = user_id('ReqPro'))
    setuser 'ReqPro'
go

Create Table RQDISCUSSIONGROUPS (
	DISCUSSIONID int DEFAULT 0 Not Null ,
	GROUPID int DEFAULT 0 Not Null)

Create Table RQDISCUSSIONREQUIREMENTS (
	DISCUSSIONID int DEFAULT 0 Not Null ,
	REQUIREMENTID int DEFAULT 0 Not Null)

Create Table RQDISCUSSIONS (
	ID int DEFAULT 0 Not Null ,
	ROOTID int DEFAULT 0 Not Null ,
	PARENTID int DEFAULT 0 Null ,
	SUBJECT varchar (255) Not Null ,
	MESSAGE text Null ,
	AUTHORID int DEFAULT 0 Not Null ,
	SUBMITDATETIME datetime Null ,
	PRIORITY tinyint DEFAULT 2 Not Null ,
	STATUS tinyint DEFAULT 1 Not Null ,
	HASRESPONSES bit DEFAULT 0 Not Null ,
	RESTRICTED tinyint DEFAULT 0 Null)

Create Table RQDISCUSSIONSREAD (
	DISCUSSIONID int DEFAULT 0 Not Null ,
	USERID int DEFAULT 0 Not Null)

Create Table RQDISCUSSIONUSERS (
	DISCUSSIONID int DEFAULT 0 Not Null ,
	USERID int DEFAULT 0 Not Null)

Create Table RQDOCUMENTHISTORY (
	ID int DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null ,
	OVERFLOWIND bit DEFAULT 0 Not Null)

Create Table RQDOCUMENTS (
	ID int DEFAULT 0 Not Null ,
	DOCUMENTTYPEID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	DESCRIPTION varchar (255) Null ,
	ITEMLABEL bit DEFAULT 1 Not Null ,
	PROTECTSTATE varchar (50) Null ,
	UNLOCKTOREVISE bit DEFAULT 0 Not Null ,
	DEFERREDRENUMBER varchar (50) Null ,
	DEFERREDRESTYLE varchar (50) Null ,
	FILEDIRECTORY varchar (255) Null ,
	FILENAME varchar (255) Not Null ,
	FILEEXTENSION varchar (255) Not Null ,
	FILEDATETIME datetime Not Null ,
	FILESIZE int DEFAULT 0 Not Null ,
	FILEFLAGS varchar (50) Null ,
	FILEVERSION int DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null ,
	OFFLINEFULLPATH varchar (255) Null ,
	OFFLINESTATUS bit DEFAULT 0 Not Null, 
	RQGUID varchar(40) Not Null,
	FLAGS int Null)

Create Table RQDOCUMENTTYPES (
	ID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	DESCRIPTION varchar (255) Null ,
	FILEEXTENSION varchar (255) Not Null ,
	DEFAULTREQUIREMENTTYPE int DEFAULT 0 Not Null ,
	TEMPLATENAME varchar (64) Null ,
	TEMPLATEDESCRIPTION varchar (255) Null ,
	TEMPLATEFILENAME varchar (255) Null ,
	TEMPLATEHELPFILE varchar (255) Null, 
	RQGUID varchar(40) Not Null)

Create Table RQDOCUMENTTYPEUSERS (
	PROJECTID int DEFAULT 0 Not Null ,
	DOCUMENTTYPEID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	ACCESSRIGHTS tinyint DEFAULT 0 Not Null)

Create Table RQEXTERNALPROJECTS (
	ID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	RQGUID varchar (40) Not Null ,
	PREFIX varchar (20) Null ,
	DIRECTORY varchar (255) Not Null ,
	FILENAME varchar (255) Not Null)

CREATE TABLE RQGENERICTABLETEMP (
	SESSIONID INT Not Null ,
	ID INT Not Null ,
	SDATA VARCHAR (255) Null ,
	LDATA INT Null)

Create Table RQHIERARCHYFINALORDERTEMP (
	SESSIONID int Not Null ,
	REQUIREMENTID int Not Null ,
	LONGTAGNUMBER varchar (255) Not Null ,
	ORDERTAG varchar (255) Not Null)

Create Table RQHIERARCHYORDEREDLEVELSTEMP (
	SESSIONID int Not Null ,
	REQUIREMENTID int Not Null ,
	LONGTAGNUMBER varchar (255) Not Null ,
	DATAORDER int IDENTITY (1, 1) Not Null)

Create Table RQHIERARCHYTABLETEMP (
	SESSIONID int Not Null ,
	REQUIREMENTKEY int Not Null ,
	LONGTAGNUMBER varchar (255) Not Null ,
	DATAORDER int Null)

Create Table RQKEYS (
	KEYCLASS varchar (50) Not Null ,
	LASTKEY int DEFAULT 0 Not Null)

Create Table RQOVERFLOWHISTORY (
	OVERFLOWTYPE tinyint DEFAULT 0 Not Null ,
	OVERFLOWID int DEFAULT 0 Not Null ,
	OVERFLOWVERSIONNUMBER varchar (50) Not Null ,
	OVERFLOWVERSIONREASON text Null)

Create Table RQOVERFLOWTEXT (
	OVERFLOWID int DEFAULT 0 Not Null ,
	OVERFLOWTEXT text Null)

Create Table RQOVERFLOWVALUES (
	OVERFLOWREQUIREMENTID int DEFAULT 0 Not Null ,
	OVERFLOWFIELDID int DEFAULT 0 Not Null ,
	OVERFLOWFIELDVALUE text Null)

Create Table RQPACKAGES (
	ID int Not Null,
	PROJECTID int Not Null,
	PARENTID int Null,
	NAME varchar(128) Not Null,
	DESCRIPTION varchar(255) Null,
	RQGUID varchar(40) Not Null)

Create Table RQPACKAGEELEMENTS (
	PACKAGEID int Not Null,
	REQUIREMENTID int Null,
	DOCUMENTID int Null,
	VIEWID int Null)

Create Table RQPROJECTDISCUSSIONS (
	PROJECTID int DEFAULT 0 Not Null ,
	DISCUSSIONID int DEFAULT 0 Not Null)

Create Table RQPROJECTDOCUMENTS (
	PROJECTID int DEFAULT 0 Not Null ,
	DOCUMENTID int DEFAULT 0 Not Null)

Create Table RQPROJECTDOCUMENTTYPES (
	PROJECTID int DEFAULT 0 Not Null ,
	DOCUMENTTYPEID int DEFAULT 0 Not Null)

Create Table RQPROJECTEXTERNALPROJECTS (
	PROJECTID int DEFAULT 0 Not Null ,
	EXTERNALPROJECTID int DEFAULT 0 Not Null ,
	CONNECTATOPEN bit DEFAULT 0 Not Null)

Create Table RQPROJECTHISTORY (
	ID int DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null ,
	OVERFLOWIND bit DEFAULT 0 Not Null)

Create Table RQPROJECTREQUIREMENTS (
	PROJECTID int DEFAULT 0 Not Null ,
	REQUIREMENTID int DEFAULT 0 Not Null)

Create Table RQPROJECTREQUIREMENTTYPES (
	PROJECTID int DEFAULT 0 Not Null ,
	REQUIREMENTTYPEID int DEFAULT 0 Not Null)

Create Table RQPROJECTS (
	ID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	PREFIX varchar (20) Null ,
	RQGUID varchar (40) Not Null ,
	DESCRIPTION varchar (255) Null ,
	DOCUMENTWORDFORMAT bit DEFAULT 0 Not Null ,
	AUTHORID int DEFAULT 0 Not Null ,
	SECURITYENABLED bit DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null ,
	RSDS varchar (255) Null,
	FLAGS int Null,
	XMLVERSION tinyint DEFAULT 0 Not Null)

Create Table RQPROJECTUSERS (
	PROJECTID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	ACCESSRIGHTS tinyint DEFAULT 0 Not Null)

Create Table RQQUERYDEFINITIONS (
	ID int DEFAULT 0 Not Null ,
	PROJECTID int Not Null,
	QUERYNAME varchar (64) Not Null ,
	QUERYDESCRIPTION varchar (255) Null ,
	QUERYUSERID int DEFAULT 0 Not Null ,
	QUERYDATETIME datetime Not Null ,
	QUERYREASON varchar (255) Null ,
	QUERYBASETYPE int DEFAULT 1 Not Null ,
	QUERYSTRING text Null,
	RQGUID varchar (40) Not Null)

Create Table RQREQUIREMENTHISTORY (
	ID int DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null ,
	OVERFLOWIND bit DEFAULT 0 Not Null)

Create Table RQREQUIREMENTS (
	ID int DEFAULT 0 Not Null ,
	REQUIREMENTTYPEID int DEFAULT 0 Not Null ,
	TAG int Not Null ,
	LASTCHILDTAG int DEFAULT 0 Null ,
	BOOKMARKNAME varchar (64) Null ,
	BOOKMARKDOCUMENTID int Null ,
	DOCUMENTPOSITION smallint DEFAULT 0 Null ,
	LONGTAGNUMBER varchar (255) Not Null ,
	REQUIREMENTPREFIX varchar (64) Not Null ,
	REQUIREMENTTEXT varchar(4000) Null ,
	OVERFLOWIND bit DEFAULT 0 Not Null ,
	DELETED bit DEFAULT 0 Not Null ,
	VERSIONNUMBER varchar (50) Not Null ,
	VERSIONLABEL varchar (255) Null ,
	VERSIONUSERID int Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar(1000) Null, 
	RQGUID varchar(40) Not Null,
	FLAGS int NULL,
	LASTDOCTEXT int NULL,
	REQUIREMENTNAME varchar(255) Null,
	SUSPECTDATETIME datetime Null)

Create Table RQREQUIREMENTTYPEFIELDS (
	REQUIREMENTTYPEID int DEFAULT 0 Not Null ,
	USERDEFINEDFIELDID int DEFAULT 0 Not Null)

Create Table RQREQUIREMENTTYPES (
	ID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	DESCRIPTION varchar (255) Null ,
	REQUIREMENTPREFIX varchar (64) Not Null ,
	REQUIREMENTSTYLE tinyint DEFAULT 0 Not Null ,
	REQUIREMENTCOLOR tinyint DEFAULT 0 Not Null ,
	REQUIREMENTMUSTCONTAIN varchar (64) Null ,
	INITIALREQNUMBER int DEFAULT 0 Not Null ,
	LASTREQNUMBER int DEFAULT 0 Null ,
	ALLOWEXTERNALREFERENCES bit DEFAULT 0 Not Null, 
	RQGUID varchar(40) Not Null)

Create Table RQREQUIREMENTTYPESTYLES (
	REQUIREMENTTYPEID int DEFAULT 0 Not Null ,
	REQTYPELEVEL smallint DEFAULT 0 Not Null ,
	STYLE varchar (255) Null)

Create Table RQREQUIREMENTTYPEUSERS (
	PROJECTID int DEFAULT 0 Not Null ,
	REQUIREMENTTYPEID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	ACCESSRIGHTS tinyint DEFAULT 0 Not Null,
	REQTEXTACCESSRIGHTS tinyint Null,
	TRACEABILITYACCESSRIGHTS tinyint Null,
	REQNAMEACCESSRIGHTS tinyint Null)

Create Table RQREQUISITE (
	DATASTRUCTURE int DEFAULT 0 Not Null ,
	REQUIREMENTTEXTSIZE int DEFAULT 0 Not Null ,
	FIELDVALUESIZE int DEFAULT 0 Not Null ,
	VERSIONREASONSIZE int DEFAULT 0 Not Null ,
	RESERVEDFLAGS int Null)

Create Table RQTORELATIONSHIPS (
	ID int IDENTITY (1, 1) Not Null ,
	REQUIREMENTID int DEFAULT 0 Not Null ,
	EXTERNALPROJECTID int DEFAULT 0 Not Null ,
	TOID int DEFAULT 0 Not Null ,
	EXTERNALPROJECTTOID int DEFAULT 0 Not Null ,
	STATE tinyint DEFAULT 0 Null ,
	TYPE tinyint DEFAULT 0 Not Null ,
	NAME varchar (64) Null ,
	VERSIONNUMBER varchar (50) Null ,
	VERSIONUSERID int DEFAULT 0 Not Null ,
	VERSIONDATETIME datetime DEFAULT (getdate()) Not Null ,
	VERSIONREASON varchar (255) Null)

Create Table RQTRACETABLEINDIR (
	SESSIONID int DEFAULT 0 Not Null ,
	ID int DEFAULT 0 Not Null)

Create Table RQTRACETABLETEMP (
	SESSIONID int DEFAULT 0 Not Null ,
	ROOTID int DEFAULT 0 Not Null ,
	ID int DEFAULT 0 Not Null ,
	PROJECTID int Not Null, 
	LVL int DEFAULT 0 Not Null,
	STATUS tinyint Null)

Create Table RQUSERDEFINEDDOCRELVALUES (
	DOCUMENTID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	RELATEDITEMID varchar (255) Not Null)

Create Table RQUSERDEFINEDFIELDS (
	ID int DEFAULT 0 Not Null ,
	LABEL varchar (32) Not Null ,
	RANK smallint DEFAULT 0 Not Null ,
	AUTOSUSPECT bit DEFAULT 0 Not Null ,
	REQUIRED bit DEFAULT 0 Not Null ,
	DATATYPE tinyint DEFAULT 0 Not Null ,
	DEFAULTVALUE varchar (255) Null ,
	FLAGS int Null ,
	DESCRIPTION varchar(255) Null ,
	FIELDPROPERTIES text Null,
	RQGUID varchar (40) Not Null)

Create Table RQUSERDEFINEDFIELDUSERS (
	PROJECTID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	ACCESSRIGHTS tinyint DEFAULT 0 Not Null)

Create Table RQUSERDEFINEDFIELDVALUES (
	REQUIREMENTID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	FIELDVALUE varchar(4000) Not Null ,
	OVERFLOWIND bit DEFAULT 0 Not Null ,
	NUMERICVALUE  float Null)

Create Table RQUSERDEFINEDLISTITEMS (
	ITEMID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	ITEMRANK smallint DEFAULT 0 Not Null ,
	ITEMTEXT varchar (64) Not Null,
	RQGUID varchar (40) Not Null)

Create Table RQUSERDEFINEDLISTITEMUSERS (
	PROJECTID int DEFAULT 0 Not Null ,
	LISTITEMID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	ACCESSRIGHTS tinyint DEFAULT 0 Not Null)

Create Table RQUSERDEFINEDLISTVALUES (
	REQUIREMENTID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	LISTITEMID int DEFAULT 0 Not Null)

Create Table RQUSERDEFINEDRELVALUES (
	REQUIREMENTID int DEFAULT 0 Not Null ,
	FIELDID int DEFAULT 0 Not Null ,
	RELATEDITEMID varchar (255) Not Null)

Create Table RQUSERGROUPS (
	ID int DEFAULT 0 Not Null ,
	NAME varchar (64) Not Null ,
	DESCRIPTION varchar (255) Null ,
	PROJECTACCESSRIGHTS tinyint DEFAULT 0 Null ,
	DOCTYPEACCESSRIGHTS tinyint DEFAULT 0 Null ,
	REQTYPEACCESSRIGHTS tinyint DEFAULT 0 Null ,
	ATTRIBUTEACCESSRIGHTS tinyint DEFAULT 3 Null ,
	LISTITEMACCESSRIGHTS tinyint DEFAULT 3 Null,
	RQGUID varchar (40) Not Null)

Create Table RQUSERS (
	ID int DEFAULT 0 Not Null ,
	LOGINNAME varchar (20) Not Null ,
	PASSWORD varchar (30) Null ,
	GROUPID int DEFAULT 0 Not Null ,
	ACTIVE bit DEFAULT 1 Not Null ,
	FULLNAME varchar (255) Null ,
	EMAILADDRESS varchar (255) Null,
	RQGUID varchar (40) Not Null)

Create Table RQVIEWS (
	ID int DEFAULT 0 Not Null ,
	PROJECTID int DEFAULT 0 Not Null ,
	REQUIREMENTTYPEID int DEFAULT 0 Not Null ,
	SECONDARYREQTYPEID int DEFAULT 0 Null ,
	VIEWNAME varchar (64) Not Null ,
	VIEWDESCRIPTION varchar (255) Null ,
	VIEWTYPE tinyint DEFAULT 0 Null ,
	VISIBILITY tinyint DEFAULT 0 Null ,
	PROPERTIES text Null ,
	QUERYID int DEFAULT 0 Null ,
	SECONDARYQUERYID int DEFAULT 0 Null ,
	VIEWUSERID int DEFAULT 0 Null ,
	VIEWDATETIME datetime Null ,
	VIEWREASON varchar (255) Null,
	RQGUID varchar (40) Not Null)

setuser
Go

/* Microsoft SQL Server - Scripting		*/
/* Database: ReqPro					            */
/* Creation Date 10/12/98 09:50:13          */
/* Version: 4.01.0013                                  */

/* Notes:  Creates all ReqPro Primary Keys. */

/* If the default Login and User scheme has been used, then create all */
/* objects under the ReqPro user.  Otherwise, create them under */
/* the current Login. */
setuser
go

If exists (select * from sysusers where uid = user_id('ReqPro'))
    setuser 'ReqPro'
go

Alter Table RQDISCUSSIONGROUPS Add Constraint RQDISCUSSIONGROUPS_PK Primary Key Clustered (GROUPID, DISCUSSIONID)
Alter Table RQDISCUSSIONREQUIREMENTS Add Constraint RQDISCUSSIONREQUIREMENTS_PK Primary Key Clustered (REQUIREMENTID, DISCUSSIONID)
Alter Table RQDISCUSSIONS Add Constraint RQDISCUSSIONS_PK Primary Key NonClustered (ID)
Alter Table RQDISCUSSIONSREAD Add Constraint RQDISCUSSIONSREAD_PK Primary Key Clustered (USERID, DISCUSSIONID)
Alter Table RQDISCUSSIONUSERS Add Constraint RQDISCUSSIONUSERS_PK Primary Key Clustered (USERID, DISCUSSIONID)
Alter Table RQDOCUMENTHISTORY Add Constraint RQDOCUMENTHISTORY_PK Primary Key Clustered (ID, VERSIONNUMBER)
Alter Table RQDOCUMENTS Add Constraint RQDOCUMENTS_PK Primary Key Clustered (ID)
Alter Table RQDOCUMENTTYPES Add Constraint RQDOCUMENTTYPES_PK Primary Key Clustered (ID)
Alter Table RQDOCUMENTTYPEUSERS Add Constraint RQDOCUMENTTYPEUSERS_PK Primary Key Clustered (PROJECTID, DOCUMENTTYPEID, USERGROUPID)
Alter Table RQEXTERNALPROJECTS Add Constraint RQEXTERNALPROJECTS_PK Primary Key Clustered (ID)
Alter Table RQKEYS Add Constraint RQKEYS_PK Primary Key NonClustered (KEYCLASS)
Alter Table RQOVERFLOWHISTORY Add Constraint RQOVERFLOWHISTORY_PK Primary Key Clustered (OVERFLOWID, OVERFLOWTYPE, OVERFLOWVERSIONNUMBER)
Alter Table RQOVERFLOWTEXT Add Constraint RQOVERFLOWTEXT_PK Primary Key Clustered (OVERFLOWID)
Alter Table RQOVERFLOWVALUES Add Constraint RQOVERFLOWVALUES_PK Primary Key Clustered (OVERFLOWREQUIREMENTID, OVERFLOWFIELDID)
Alter Table RQPACKAGES Add Constraint RQPACKAGES_PK Primary Key Clustered (ID)
Alter Table RQPROJECTDISCUSSIONS Add Constraint RQPROJECTDISCUSSIONS_PK Primary Key Clustered (PROJECTID, DISCUSSIONID)
Alter Table RQPROJECTDOCUMENTS Add Constraint RQPROJECTDOCUMENTS_PK Primary Key Clustered (PROJECTID, DOCUMENTID)
Alter Table RQPROJECTDOCUMENTTYPES Add Constraint RQPROJECTDOCUMENTTYPES_PK Primary Key Clustered (PROJECTID, DOCUMENTTYPEID)
Alter Table RQPROJECTEXTERNALPROJECTS Add Constraint RQPROJECTEXTERNALPROJECTS_PK Primary Key Clustered (PROJECTID, EXTERNALPROJECTID)
Alter Table RQPROJECTHISTORY Add Constraint RQPROJECTHISTORY_PK Primary Key Clustered (ID, VERSIONNUMBER)
Alter Table RQPROJECTREQUIREMENTS Add Constraint RQPROJECTREQUIREMENTS_PK Primary Key Clustered (PROJECTID, REQUIREMENTID)
Alter Table RQPROJECTREQUIREMENTTYPES Add Constraint RQPROJECTREQUIREMENTTYPES_PK Primary Key Clustered (PROJECTID, REQUIREMENTTYPEID)
Alter Table RQPROJECTS Add Constraint RQPROJECTS_PK Primary Key Clustered (ID)
Alter Table RQPROJECTUSERS Add Constraint RQPROJECTUSERS_PK Primary Key Clustered (PROJECTID, USERGROUPID)
Alter Table RQQUERYDEFINITIONS Add Constraint RQQUERYDEFINITIONS_PK Primary Key NonClustered (ID)
Alter Table RQREQUIREMENTHISTORY Add Constraint RQREQUIREMENTHISTORY_PK Primary Key Clustered (ID, VERSIONNUMBER)
Alter Table RQREQUIREMENTS Add Constraint RQREQUIREMENTS_PK Primary Key Clustered (ID)
Alter Table RQREQUIREMENTTYPEFIELDS Add Constraint RQREQUIREMENTTYPEFIELDS_PK Primary Key Clustered (REQUIREMENTTYPEID, USERDEFINEDFIELDID)
Alter Table RQREQUIREMENTTYPES Add Constraint RQREQUIREMENTTYPES_PK Primary Key Clustered (ID)
Alter Table RQREQUIREMENTTYPESTYLES Add Constraint RQREQUIREMENTTYPESTYLES_PK Primary Key Clustered (REQUIREMENTTYPEID, REQTYPELEVEL)
Alter Table RQREQUIREMENTTYPEUSERS Add Constraint RQREQUIREMENTTYPEUSERS_PK Primary Key Clustered (USERGROUPID, PROJECTID, REQUIREMENTTYPEID)
Alter Table RQTORELATIONSHIPS Add Constraint RQTORELATIONSHIPS_PK Primary Key NonClustered (ID)
Alter Table RQUSERDEFINEDFIELDS Add Constraint RQUSERDEFINEDFIELDS_PK Primary Key Clustered (ID)
Alter Table RQUSERDEFINEDFIELDUSERS Add Constraint RQUSERDEFINEDFIELDUSERS_PK Primary Key Clustered (PROJECTID, FIELDID, USERGROUPID)
Alter Table RQUSERDEFINEDFIELDVALUES Add Constraint RQUSERDEFINEDFIELDVALUES_PK Primary Key Clustered (REQUIREMENTID, FIELDID)
Alter Table RQUSERDEFINEDLISTITEMS Add Constraint RQUSERDEFINEDLISTITEMS_PK Primary Key NonClustered (ITEMID)
Alter Table RQUSERDEFINEDLISTITEMUSERS Add Constraint RQUSERDEFINEDLISTITEMUSERS_PK Primary Key Clustered (LISTITEMID, PROJECTID, USERGROUPID)
Alter Table RQUSERDEFINEDLISTVALUES Add Constraint RQUSERDEFINEDLISTVALUES_PK Primary Key Clustered (REQUIREMENTID, FIELDID, LISTITEMID)
Alter Table RQUSERDEFINEDDOCRELVALUES Add Constraint RQUDDOCRELVALS_PK Primary Key Clustered (DOCUMENTID, FIELDID, RELATEDITEMID)
Alter Table RQUSERDEFINEDRELVALUES Add Constraint RQUDRELVALS_PK Primary Key Clustered (REQUIREMENTID, FIELDID, RELATEDITEMID)
Alter Table RQUSERGROUPS Add Constraint RQUSERGROUPS_PK Primary Key Clustered (ID)
Alter Table RQUSERS Add Constraint RQUSERS_PK Primary Key Clustered (ID)
Alter Table RQVIEWS Add Constraint RQVIEWS_PK Primary Key NonClustered (ID)

setuser
go

/* Microsoft SQL Server - Scripting		*/
/* Database: ReqPro					            */
/* CreatiOn Date 11/16/98 11:46:07 			*/
/* Version: 4.02d.1                                  */

/* Notes: Creates all ReqPro Indexes. */

/* If the default Login and User scheme has been used, then create all */
/* objects under the ReqPro user.  Otherwise, create them under */
/* the current Login. */
Setuser
Go

If Exists (select * from sysusers where uid = user_id('ReqPro'))
    Setuser 'ReqPro'
Go 

/* RqDiscussionGroups */
Create  Index DISCUSSIONID On RQDISCUSSIONGROUPS(DISCUSSIONID)

/* RqDiscussionRequirements */
Create  Index DISCUSSIONID On RQDISCUSSIONREQUIREMENTS(DISCUSSIONID)

/* RqDiscussions */
Create  Index ROOTID On RQDISCUSSIONS(ROOTID)

/* RqDiscussionsRead */
Create  Index DISCUSSIONID On RQDISCUSSIONSREAD(DISCUSSIONID)

/* RqDiscussionUsers */
Create  Index DISCUSSIONID On RQDISCUSSIONUSERS(DISCUSSIONID)

/* RqDocumentHistory */
Create  Index VERSIONUSERID On RQDOCUMENTHISTORY(VERSIONUSERID)

/* RqDocuments */
Create  Index DOCUMENTTYPEID On RQDOCUMENTS(DOCUMENTTYPEID)
Create  Index VERSIONUSERID On RQDOCUMENTS(VERSIONUSERID)
Create  Index RQGUID On RQDOCUMENTS(RQGUID)

/* RqDocumentTypeUsers */
Create  Index DOCUMENTTYPEID On RQDOCUMENTTYPEUSERS(DOCUMENTTYPEID)
Create  Index PROJECTID On RQDOCUMENTTYPEUSERS(PROJECTID)

/* RqDocumentTypes */
Create  Index RQGUID On RQDOCUMENTTYPES(RQGUID)

/* RqExternalProjects */

/* RqOverflowHistory */

/* RqOverflowText */

/* RqOverflowValues */

/* RqPackages */
Create  Index PARENTID On RQPACKAGES(PARENTID)
Create	Unique Index PROJECTPARENTNAME On RQPACKAGES(PROJECTID,PARENTID,NAME)
Create	Index RQGUID On RQPACKAGES(RQGUID)

/* RqPackageElements */
Create Index PACKAGEID On RQPACKAGEELEMENTS(PACKAGEID)
Create Index REQUIREMENTID On RQPACKAGEELEMENTS(REQUIREMENTID)
Create Unique Index REQUIREMENTIDDOCUMENTIDVIEWID On RQPACKAGEELEMENTS(REQUIREMENTID,DOCUMENTID,VIEWID)

/* RqProjectDiscussions */
Create  Index DISCUSSIONID On RQPROJECTDISCUSSIONS(DISCUSSIONID)

/* RqProjectDocuments */

/* RqProjectDocumentTypes */

/* RqProjectExternalProjects */
Create  Index EXTERNALPROJECTID On RQPROJECTEXTERNALPROJECTS(EXTERNALPROJECTID)
Create  Index PROJECTID On RQPROJECTEXTERNALPROJECTS(PROJECTID)

/* RqProjectHistory */
Create  Index VERSIONUSERID On RQPROJECTHISTORY(VERSIONUSERID)

/* RqProjectRequirements */

/* RqProjectRequirementTypes */

/* RqProjects */
Create  Index RQPROJECTSRQPROJECTUSERS On RQPROJECTS(AUTHORID)
Create  Index RQUSERGROUPSRQPROJECTUSERS On RQPROJECTS(VERSIONUSERID)
Create  Index RQGUID On RQPROJECTS(RQGUID)

/* RqProjectUsers */

/* RqQueryDefinitions */
Create Index QUERYUSERID On RQQUERYDEFINITIONS(QUERYUSERID)
Create Index RQGUID On RQQUERYDEFINITIONS(RQGUID)

/* RqRequirementHistory */
Create  Index VERSIONUSERID On RQREQUIREMENTHISTORY(VERSIONUSERID)

/* RqRequirements */
Create  Index LONGTAGNUMBER On RQREQUIREMENTS(LONGTAGNUMBER)
Create  Index REQUIREMENTTYPEID On RQREQUIREMENTS(REQUIREMENTTYPEID)
Create  Index BOOKMARKDOCUMENTID On RQREQUIREMENTS(BOOKMARKDOCUMENTID)
Create  Index VERSIONUSERID On RQREQUIREMENTS(VERSIONUSERID)
Create  Index RQGUID On RQREQUIREMENTS(RQGUID)

/* RqRequirementTypeFields */

/* RqRequirementTypes */
Create  Index RQGUID On RQREQUIREMENTTYPES(RQGUID)

/* RqRequirementTypeStyles */
Create  Index REQUIREMENTTYPEID On RQREQUIREMENTTYPESTYLES(REQUIREMENTTYPEID)

/* RqRequirementTypeUsers */
Create  Index PROJECTID On RQREQUIREMENTTYPEUSERS(PROJECTID)

/* RqToRelationships */
Create  Index EXTERNALPROJECTID On RQTORELATIONSHIPS(EXTERNALPROJECTID)
Create  Index EXTERNALPROJECTTOID On RQTORELATIONSHIPS(EXTERNALPROJECTTOID)
Create  Index REQUIREMENTID On RQTORELATIONSHIPS(REQUIREMENTID)
Create  Index TOID On RQTORELATIONSHIPS(TOID)
Create  Index VERSIONUSERID On RQTORELATIONSHIPS(VERSIONUSERID)

/* RqUserDefinedFields */
Create Index RQGUID On RQUSERDEFINEDFIELDS(RQGUID)

/* RqUserDefinedFieldUsers */
Create  Index PROJECTID On RQUSERDEFINEDFIELDUSERS(PROJECTID)
Create  Index FIELDID On RQUSERDEFINEDFIELDUSERS(FIELDID)
Create  Index USERGROUPID On RQUSERDEFINEDFIELDUSERS(USERGROUPID)

/* RqUserDefinedListItems */
Create  Index FIELDID On RQUSERDEFINEDLISTITEMS(FIELDID)
Create Index RQGUID On RQUSERDEFINEDLISTITEMS(RQGUID)

/* RqUserDefinedFieldValues */
Create  Index REQUIREMENTID On RQUSERDEFINEDFIELDVALUES(REQUIREMENTID)
Create  Index FIELDID On RQUSERDEFINEDFIELDVALUES(FIELDID)

/* RqUserDefinedListItemUsers */
Create  Index PROJECTID On RQUSERDEFINEDLISTITEMUSERS(PROJECTID)
Create  Index USERGROUPID On RQUSERDEFINEDLISTITEMUSERS(USERGROUPID)

/* RqUserDefinedListValues */
Create  Index FIELDID On RQUSERDEFINEDLISTVALUES(FIELDID)
Create  Index LISTITEMID On RQUSERDEFINEDLISTVALUES(LISTITEMID)

/* RqUserDefinedDocRelValues */
Create Index DOCUMENTID on RQUSERDEFINEDDOCRELVALUES(DOCUMENTID)
Create Index FIELDID on RQUSERDEFINEDDOCRELVALUES(FIELDID)

/* RqUserDefinedRelValues */
Create Index REQUIREMENTID on RQUSERDEFINEDRELVALUES(REQUIREMENTID)
Create Index FIELDID on RQUSERDEFINEDRELVALUES(FIELDID)

/* RqUserGroups */
Create Index NAME On RQUSERGROUPS(NAME)
Create Index RQGUID On RQUSERGROUPS(RQGUID)

/* RqUsers */
Create Index LOGINNAME On RQUSERS(LOGINNAME)
Create Index GROUPID On RQUSERS(GROUPID)
Create Index RQGUID On RQUSERS(RQGUID)

/* RqViews */
Create  Index PROJECTID On RQVIEWS(PROJECTID)
Create  Index QUERYID On RQVIEWS(QUERYID)
Create  Index REQUIREMENTTYPEID On RQVIEWS(REQUIREMENTTYPEID)
Create  Index SECONDARYQUERYID On RQVIEWS(SECONDARYQUERYID)
Create  Index SECONDARYREQTYPEID On RQVIEWS(SECONDARYREQTYPEID)
Create  Index VIEWUSERID On RQVIEWS(VIEWUSERID)
Create  Index RQGUID On RQVIEWS(RQGUID)

/* RQGENERICTABLETEMP */
Create Index GTTEMP_SESSIONID On RQGENERICTABLETEMP(SESSIONID)
Create Index GTTEMP_ID On RQGENERICTABLETEMP(ID)

/* RQHIERARCHYTABLETEMP */
Create Index HTT_SID On RQHIERARCHYTABLETEMP(SESSIONID)

/* New objects for 7.1 */
ALTER TABLE RqRequirementHistory ADD FLAGS INT  NOT NULL DEFAULT 0 ;
ALTER TABLE RqDocumentHistory ADD FLAGS INT  NOT NULL DEFAULT 0 ;
ALTER TABLE RqProjectHistory ADD FLAGS INT  NOT NULL DEFAULT 0 ;
ALTER TABLE RqProjects ADD WEBSERVER VARCHAR(255);


Create Table RQPACKAGEUSERS (
	PACKAGEID int DEFAULT 0 Not Null ,
	USERGROUPID int DEFAULT 0 Not Null ,
	PACKAGEACCESSRIGHTS tinyint DEFAULT Null,
	REQUIREMENTACCESSRIGHTS tinyint DEFAULT Null,
	DOCUMENTACCESSRIGHTS tinyint DEFAULT Null,
	VIEWACCESSRIGHTS tinyint DEFAULT Null);

Alter Table RQPACKAGEUSERS Add Constraint RQPACKAGEUSERS_PK Primary Key Clustered (PACKAGEID, USERGROUPID);

ALTER TABLE RQPACKAGEUSERS WITH CHECK ADD  CONSTRAINT FK_RQPACKAGEUSERS_RQPACKAGES FOREIGN KEY(PACKAGEID)
REFERENCES RQPACKAGES (ID)
ON DELETE CASCADE;

ALTER TABLE RQPACKAGEUSERS  WITH CHECK ADD  CONSTRAINT FK_RQPACKAGEUSERS_RQUSERGROUPS FOREIGN KEY (USERGROUPID)
REFERENCES RQUSERGROUPS (ID)
ON DELETE CASCADE;


CREATE TABLE RQRESOURCES (
       ID                   INT DEFAULT 0 NOT NULL,
       NAME                 VARCHAR(255) NOT NULL,
       TYPE                 VARCHAR(255) NOT NULL,
       REQUIREMENTID        INT ,
       RESOURCEOBJ          IMAGE,
       VERSIONDATETIME      DATETIME DEFAULT (getdate())NOT NULL,
       RQGUID               VARCHAR(40) NOT NULL,
       FLAGS INT  NOT NULL DEFAULT 0 
);

  
ALTER TABLE RQRESOURCES
       ADD  CONSTRAINT RQRESOURCES_PK PRIMARY KEY (ID);

CREATE INDEX RQRES_RQGUID_X ON RQRESOURCES (RQGUID); 

CREATE INDEX RQRES_DATE_X on RQRESOURCES (REQUIREMENTID, VERSIONDATETIME);

ALTER TABLE RQRESOURCES
       ADD  CONSTRAINT RQRES_REQID_FK FOREIGN KEY (REQUIREMENTID)
	REFERENCES RQREQUIREMENTS ON DELETE CASCADE ;


Setuser
Go

